@@ -40,6 +40,11 @@ class App(object):
         self.app = FastAPI(title='AppZoo')
         # self.app = app_
 
+        # 增加配置项，方便热更新
+        self.config = None # self.config===body_json
+        self.add_route_plus(lambda k: self.config, '/app-config')
+        self.add_route_plus(self._set_config, '/set-app-config', methods="POST")
+
         # 原生接口
         self.get = self.app.get
         self.post = self.app.post
@@ -80,7 +85,7 @@ class App(object):
         handler = self._handler(func, method, **kwargs)
         self.app.api_route(path=path, methods=[method])(handler)
 
-    def add_route_plus(self, path='/xxx', func=None, method="GET", **kwargs):
+    def add_route_plus(self, func, path=None, methods: Union[List, str] = "GET", **kwargs):
         """
 
         :param path:
@@ -98,10 +103,16 @@ class App(object):
         :return:
         """
         assert isinstance(func, Callable)
+        if isinstance(methods, str):
+            methods = [methods]
+
+        if path is None:
+            path = f"""/{func.__name__.replace('_', '-')}"""  # todo 前缀
+
+        assert path.startswith('/')
 
         handler = self._handler_plus(func, **kwargs)
-
-        self.app.api_route(path=path, methods=[method])(handler)  # method
+        self.app.api_route(path=path, methods=methods)(handler)  # method
 
     def add_route_uploadfiles(self, path='/xxx', func=lambda x='demo': x, **kwargs):
         """
@@ -243,13 +254,13 @@ class App(object):
     @staticmethod
     def _try_func_plus(input, func, **kwargs):
 
-        output = OrderedDict(code=0, msg="SUCCESS", **kwargs)
+        output = OrderedDict(code=200, msg="SUCCESS", **kwargs)
 
         try:
             output['data'] = func(input)
 
         except Exception as error:
-            output['code'] = 1  # 通用错误
+            output['code'] = 500  # 通用错误
             output['msg'] = traceback.format_exc().strip()  # debug状态获取详细信息
 
             logger.error(output['msg'])
@@ -265,6 +276,12 @@ class App(object):
     def app_from(self, file=__file__, app='app_'):
         return f"{Path(file).stem}:{app}"
 
+    @lru_cache()
+    def _set_config(self, kwargs: str):
+        self.config = json_loads(kwargs)
+        logger.warning("Configuration item is modified ！！！")
+        return self.config
+
 
 if __name__ == '__main__':
     import uvicorn
