@@ -12,7 +12,7 @@
 import os
 from PIL import Image
 from paddleocr import draw_ocr
-from appzoo.utils.zk_utils import get_zk_config
+from meutils.zk_utils import get_zk_config
 
 fds_url = get_zk_config('/mipush/cfg')['fds_url']
 
